import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { YMapListener, YMapListenerProps } from '@yandex/ymaps3-types';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapComponent } from '../y-map/y-map.component';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapListener](https://yandex.ru/dev/jsapi30/doc/en/ref/#class-ymaplistener) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 9,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *
 *   <y-map-listener
 *     [props]="{
 *       onClick: onClick,
 *     }"
 *   />
 * </y-map>
 * ```
 */
export declare class YMapListenerDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yMapComponent;
    private readonly destroy$;
    private listener?;
    /**
     * See the API entity documentation for detailed information. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/en/ref/#YMapListenerProps}
     */
    props: YMapListenerProps;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapListener>>;
    constructor(ngZone: NgZone, yMapComponent: YMapComponent);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapListenerDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapListenerDirective, "y-map-listener", never, { "props": { "alias": "props"; "required": true; }; }, { "ready": "ready"; }, never, never, true, never>;
}
