import { AfterViewInit, ElementRef, EventEmitter, NgZone, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { YMapMarker, YMapMarkerProps } from '@yandex/ymaps3-types';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapComponent } from '../y-map/y-map.component';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapMarker](https://yandex.ru/dev/jsapi30/doc/en/ref/#class-ymapmarker) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments. `YMapMarker['element']` can only be projected, see the example below.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 9,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *   <y-map-default-features-layer />
 *
 *   <y-map-marker
 *     [props]="{
 *       coordinates: [-0.127696, 51.507351],
 *       draggable: true,
 *     }"
 *   >
 *     <img
 *       width="64"
 *       height="64"
 *       style="border-radius: 50%"
 *       src="https://cdn.openart.ai/published/nI5hC8sFzqKnKbJtW1hA/ExVfxYNJ_E0Yh_256.webp"
 *       alt="Bulldog"
 *     />
 *   </y-map-marker>
 * </y-map>
 * ```
 */
export declare class YMapMarkerDirective implements AfterViewInit, OnDestroy, OnChanges {
    private readonly ngZone;
    private readonly elementRef;
    private readonly yMapComponent;
    private readonly destroy$;
    private marker?;
    private element?;
    /**
     * See the API entity documentation for detailed information. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapMarkerProps}
     */
    props: YMapMarkerProps;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapMarker>>;
    constructor(ngZone: NgZone, elementRef: ElementRef<HTMLElement>, yMapComponent: YMapComponent);
    ngOnChanges(changes: SimpleChanges): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapMarkerDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapMarkerDirective, "y-map-marker", never, { "props": { "alias": "props"; "required": true; }; }, { "ready": "ready"; }, never, never, true, never>;
}
