import { AfterViewInit, ElementRef, EventEmitter, NgZone, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { YMap, YMapEntity, YMapProps } from '@yandex/ymaps3-types';
import { BehaviorSubject } from 'rxjs';
import { YApiLoaderService } from '../../../services/y-api-loader/y-api-loader.service';
import { YReadyEvent } from '../../../types/y-ready-event';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMap](https://yandex.ru/dev/jsapi30/doc/ru/ref/#class-ymap) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 10,
 *     },
 *     theme: 'dark',
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 * </y-map>
 * ```
 */
export declare class YMapComponent implements AfterViewInit, OnChanges, OnDestroy {
    private readonly yaApiLoaderService;
    private readonly ngZone;
    readonly container: ElementRef;
    private readonly destroy$;
    map$: BehaviorSubject<YMap | null>;
    /**
     * See the API entity documentation for detailed information. Supports updates.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapProps}
     */
    props: YMapProps;
    /**
     * See the API entity documentation for detailed information.
     */
    children?: YMapEntity<unknown, object>[];
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMap>>;
    constructor(yaApiLoaderService: YApiLoaderService, ngZone: NgZone);
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private createMap;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<YMapComponent, "y-map", never, { "props": { "alias": "props"; "required": true; }; "children": { "alias": "children"; "required": false; }; }, { "ready": "ready"; }, never, never, true, never>;
}
