import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { YMap } from '@yandex/ymaps3-types';
import { YMapControlCommonButton, YMapControlCommonButtonProps } from '@yandex/ymaps3-types/imperative/YMapControl';
import { ComplexOptions } from '../../../types/complex-options';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapControlsDirective } from '../y-map-controls/y-map-controls.directive';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapControlCommonButton](https://yandex.ru/dev/jsapi30/doc/ru/ref/#class-ymapcontrolcommonbutton) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments. This component must be used inside a `y-map-controls` component.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 9,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *
 *   <y-map-controls [props]="{ position: 'top' }">
 *     <y-map-control-common-button [props]="{ text: 'Hello' }" />
 *   </y-map-controls>
 * </y-map>
 * ```
 */
export declare class YMapControlCommonButtonDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yMapControlsDirective;
    private readonly destroy$;
    private control?;
    /**
     * Button properties. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapControlCommonButtonProps}
     */
    props: YMapControlCommonButtonProps;
    /**
     * See the API entity documentation for detailed information.
     */
    options?: ComplexOptions<YMap>;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapControlCommonButton>>;
    constructor(ngZone: NgZone, yMapControlsDirective: YMapControlsDirective);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapControlCommonButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapControlCommonButtonDirective, "y-map-control-common-button", never, { "props": { "alias": "props"; "required": true; }; "options": { "alias": "options"; "required": false; }; }, { "ready": "ready"; }, never, never, true, never>;
}
