import { AfterViewInit, ElementRef, EventEmitter, NgZone, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { YMapControl, YMapControlProps } from '@yandex/ymaps3-types/imperative/YMapControl';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapControlsDirective } from '../y-map-controls/y-map-controls.directive';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapControl](https://yandex.ru/dev/jsapi30/doc/ru/ref/#class-ymapcontrol) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments. This component must be used inside a `y-map-controls` component.
 * Custom HTML can only be projected, see the example below.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 9,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *
 *   <y-map-controls [props]="{ position: 'top' }">
 *     <y-map-control>
 *       <p>Custom HTML</p>
 *     </y-map-control>
 *   </y-map-controls>
 * </y-map>
 * ```
 */
export declare class YMapControlDirective implements AfterViewInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly elementRef;
    private readonly yMapControlsDirective;
    private readonly destroy$;
    private control?;
    private element?;
    /**
     * See the API entity documentation for detailed information. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapControlProps}
     */
    props: YMapControlProps;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapControl>>;
    constructor(ngZone: NgZone, elementRef: ElementRef<HTMLElement>, yMapControlsDirective: YMapControlsDirective);
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    /**
     * To render a control, a container is required.
     * This method isolates all the container creation logic and returns the entity.
     */
    private createControlContainer;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapControlDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapControlDirective, "y-map-control", never, { "props": { "alias": "props"; "required": false; }; }, { "ready": "ready"; }, never, never, true, never>;
}
