import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { YMapControls, YMapControlsProps, YMapEntity } from '@yandex/ymaps3-types';
import { BehaviorSubject } from 'rxjs';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapComponent } from '../../common/y-map/y-map.component';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapControls](https://yandex.ru/dev/jsapi30/doc/ru/ref/#class-ymapcontrols) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 9,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *
 *   <y-map-controls [props]="{ position: 'top' }">
 *     ...
 *   </y-map-controls>
 * </y-map>
 * ```
 */
export declare class YMapControlsDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yMapComponent;
    private readonly destroy$;
    controls$: BehaviorSubject<YMapControls | null>;
    /**
     * Controls properties. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapControlsProps}
     */
    props: YMapControlsProps;
    /**
     * See the API entity documentation for detailed information.
     */
    children?: YMapEntity<unknown, object>[];
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapControls>>;
    constructor(ngZone: NgZone, yMapComponent: YMapComponent);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapControlsDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapControlsDirective, "y-map-controls", never, { "props": { "alias": "props"; "required": true; }; "children": { "alias": "children"; "required": false; }; }, { "ready": "ready"; }, never, never, true, never>;
}
