import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { YMapScaleControl, YMapScaleControlProps } from '@yandex/ymaps3-types';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapControlsDirective } from '../y-map-controls/y-map-controls.directive';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapScaleControl](https://yandex.ru/dev/jsapi30/doc/ru/ref/#class-ymapscalecontrol) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments. This component must be used inside a `y-map-controls` component.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 9,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *
 *   <y-map-controls [props]="{ position: 'top' }">
 *     <y-map-scale-control />
 *   </y-map-controls>
 * </y-map>
 * ```
 */
export declare class YMapScaleControlDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yMapControlsDirective;
    private readonly destroy$;
    private control?;
    /**
     * See the API entity documentation for detailed information. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapScaleControlProps}
     */
    props: YMapScaleControlProps;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapScaleControl>>;
    constructor(ngZone: NgZone, yMapControlsDirective: YMapControlsDirective);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapScaleControlDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapScaleControlDirective, "y-map-scale-control", never, { "props": { "alias": "props"; "required": false; }; }, { "ready": "ready"; }, never, never, true, never>;
}
