import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { YMap } from '@yandex/ymaps3-types';
import { YMapZoomControl, YMapZoomControlProps } from '@yandex/ymaps3-types/packages/controls';
import { ComplexOptions } from '../../../types/complex-options';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapControlsDirective } from '../y-map-controls/y-map-controls.directive';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapZoomControl](https://yandex.ru/dev/jsapi30/doc/ru/ref/packages/controls/#class-ymapzoomcontrol) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments. This component must be used inside a `y-map-controls` component.
 * This component is from the `@yandex/ymaps3-controls@0.0.1` package, which is asynchronously loaded when you use this component.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 9,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *
 *   <y-map-controls [props]="{ position: 'top' }">
 *     <y-map-zoom-control-button />
 *   </y-map-controls>
 * </y-map>
 * ```
 */
export declare class YMapZoomControlDirective implements OnInit, OnChanges, OnDestroy {
    private readonly ngZone;
    private readonly yMapControlsDirective;
    private readonly destroy$;
    private control?;
    /**
     * See the API entity documentation for detailed information. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/packages/controls/#YMapZoomControlProps}
     */
    props: YMapZoomControlProps;
    /**
     * See the API entity documentation for detailed information.
     */
    options?: ComplexOptions<YMap>;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapZoomControl>>;
    constructor(ngZone: NgZone, yMapControlsDirective: YMapControlsDirective);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapZoomControlDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapZoomControlDirective, "y-map-zoom-control-button", never, { "props": { "alias": "props"; "required": false; }; "options": { "alias": "options"; "required": false; }; }, { "ready": "ready"; }, never, never, true, never>;
}
