import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { YMap, YMapDefaultFeaturesLayer, YMapDefaultFeaturesLayerProps } from '@yandex/ymaps3-types';
import { ComplexOptions } from '../../../types/complex-options';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapComponent } from '../../common/y-map/y-map.component';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapDefaultFeaturesLayer](https://yandex.ru/dev/jsapi30/doc/ru/ref/#class-ymapdefaultfeatureslayer) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 10,
 *     },
 *   }"
 * >
 *   <y-map-default-features-layer />
 * </y-map>
 * ```
 */
export declare class YMapDefaultFeaturesLayerDirective implements OnInit, OnDestroy, OnChanges {
    private readonly ngZone;
    private readonly yMapComponent;
    private readonly destroy$;
    private layer?;
    /**
     * See the API entity documentation for detailed information. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapDefaultFeaturesLayerProps}
     */
    props: YMapDefaultFeaturesLayerProps;
    /**
     * See the API entity documentation for detailed information.
     */
    options?: ComplexOptions<YMap>;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapDefaultFeaturesLayer>>;
    constructor(ngZone: NgZone, yMapComponent: YMapComponent);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapDefaultFeaturesLayerDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapDefaultFeaturesLayerDirective, "y-map-default-features-layer", never, { "props": { "alias": "props"; "required": false; }; "options": { "alias": "options"; "required": false; }; }, { "ready": "ready"; }, never, never, true, never>;
}
