import { EventEmitter, NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { YMapLayer, YMapLayerProps } from '@yandex/ymaps3-types';
import { YReadyEvent } from '../../../types/y-ready-event';
import { YMapComponent } from '../../common/y-map/y-map.component';
import * as i0 from "@angular/core";
/**
 * This component wraps the [ymaps3.YMapLayer](https://yandex.ru/dev/jsapi30/doc/ru/ref/#class-ymaplayer) class from the Yandex.Maps API.
 * All component inputs are named the same as the API class constructor arguments.
 *
 * ```html
 * <y-map
 *   [props]="{
 *     location: {
 *       center: [-0.127696, 51.507351],
 *       zoom: 10,
 *     },
 *   }"
 * >
 *   <y-map-default-scheme-layer />
 *
 *   <y-map-layer
 *     [props]="{
 *       type: 'markers',
 *       zIndex: 1800,
 *     }"
 *   />
 * </y-map>
 * ```
 */
export declare class YMapLayerDirective implements OnInit, OnDestroy, OnChanges {
    private readonly ngZone;
    private readonly yMapComponent;
    private readonly destroy$;
    private layer?;
    /**
     * See the API entity documentation for detailed information. Supports ngOnChanges.
     * {@link https://yandex.ru/dev/jsapi30/doc/ru/ref/#YMapLayerProps}
     */
    props: YMapLayerProps;
    /**
     * The entity instance is created. This event runs outside an Angular zone.
     */
    ready: EventEmitter<YReadyEvent<YMapLayer>>;
    constructor(ngZone: NgZone, yMapComponent: YMapComponent);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<YMapLayerDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<YMapLayerDirective, "y-map-layer", never, { "props": { "alias": "props"; "required": true; }; }, { "ready": "ready"; }, never, never, true, never>;
}
